@@ -72,6 +72,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CheckFunction(self, request):
+        """本接口用于数据加工DSL函数的语法校验。
+
+        :param request: Request instance for CheckFunction.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CheckFunctionRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CheckFunctionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CheckFunction", params, headers=headers)
+            response = json.loads(body)
+            model = models.CheckFunctionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CheckRechargeKafkaServer(self, request):
         """本接口用于校验Kafka服务集群是否可以正常访问
 
@@ -164,6 +187,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAlarmShield(self, request):
+        """该接口用于创建告警屏蔽规则。
+
+        :param request: Request instance for CreateAlarmShield.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CreateAlarmShieldRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateAlarmShieldResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAlarmShield", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAlarmShieldResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateConfig(self, request):
         """创建采集规则配置
 
@@ -211,7 +257,7 @@ class ClsClient(AbstractClient):
 
 
     def CreateConsumer(self, request):
-        """本接口用于创建投递任务
+        """本接口用于创建投递CKafka任务
 
         :param request: Request instance for CreateConsumer.
         :type request: :class:`tencentcloud.cls.v20201016.models.CreateConsumerRequest`
@@ -279,6 +325,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateDeliverCloudFunction(self, request):
+        """本接口用于创建投递SCF任务
+
+        :param request: Request instance for CreateDeliverCloudFunction.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CreateDeliverCloudFunctionRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateDeliverCloudFunctionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateDeliverCloudFunction", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateDeliverCloudFunctionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateExport(self, request):
         """本接口仅创建下载任务，任务返回的下载地址，请用户调用DescribeExports查看任务列表。其中有下载地址CosPath参数。参考文档https://cloud.tencent.com/document/product/614/56449
 
@@ -509,6 +578,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteAlarmShield(self, request):
+        """该接口用于删除告警屏蔽规则。
+
+        :param request: Request instance for DeleteAlarmShield.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteAlarmShieldRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteAlarmShieldResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAlarmShield", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAlarmShieldResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteConfig(self, request):
         """删除采集规则配置
 
@@ -854,6 +946,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAlarmShields(self, request):
+        """获取告警屏蔽配置规则
+
+        :param request: Request instance for DescribeAlarmShields.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeAlarmShieldsRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeAlarmShieldsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAlarmShields", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAlarmShieldsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAlarms(self, request):
         """本接口用于获取告警策略列表。
 
@@ -1177,7 +1292,8 @@ class ClsClient(AbstractClient):
 
 
     def DescribeLogContext(self, request):
-        """本接口用于搜索日志上下文附近的内容
+        """本接口用于搜索日志上下文附近的内容，详情参考[上下文检索](https://cloud.tencent.com/document/product/614/53248)。
+        API返回数据包最大49MB，建议启用 gzip 压缩（HTTP Request Header Accept-Encoding:gzip）。
 
         :param request: Request instance for DescribeLogContext.
         :type request: :class:`tencentcloud.cls.v20201016.models.DescribeLogContextRequest`
@@ -1292,7 +1408,7 @@ class ClsClient(AbstractClient):
 
 
     def DescribeMachines(self, request):
-        """获取制定机器组下的机器状态
+        """获取指定机器组下的机器状态
 
         :param request: Request instance for DescribeMachines.
         :type request: :class:`tencentcloud.cls.v20201016.models.DescribeMachinesRequest`
@@ -1430,7 +1546,7 @@ class ClsClient(AbstractClient):
 
 
     def GetAlarmLog(self, request):
-        """本接口用于获取告警任务历史
+        """本接口用于获取告警策略执行详情
 
         :param request: Request instance for GetAlarmLog.
         :type request: :class:`tencentcloud.cls.v20201016.models.GetAlarmLogRequest`
@@ -1521,6 +1637,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyAlarmShield(self, request):
+        """该接口用于修改告警屏蔽规则。
+
+        :param request: Request instance for ModifyAlarmShield.
+        :type request: :class:`tencentcloud.cls.v20201016.models.ModifyAlarmShieldRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.ModifyAlarmShieldResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAlarmShield", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAlarmShieldResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyConfig(self, request):
         """修改采集规则配置
 
@@ -1568,7 +1707,7 @@ class ClsClient(AbstractClient):
 
 
     def ModifyConsumer(self, request):
-        """本接口用于修改投递任务
+        """本接口用于修改投递Ckafka任务
 
         :param request: Request instance for ModifyConsumer.
         :type request: :class:`tencentcloud.cls.v20201016.models.ModifyConsumerRequest`
@@ -1866,6 +2005,52 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def QueryMetric(self, request):
+        """查询指定时刻指标的最新值
+
+        :param request: Request instance for QueryMetric.
+        :type request: :class:`tencentcloud.cls.v20201016.models.QueryMetricRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.QueryMetricResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryMetric", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryMetricResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def QueryRangeMetric(self, request):
+        """查询指定时间范围内指标的变化趋势
+
+        :param request: Request instance for QueryRangeMetric.
+        :type request: :class:`tencentcloud.cls.v20201016.models.QueryRangeMetricRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.QueryRangeMetricResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryRangeMetric", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryRangeMetricResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RetryShipperTask(self, request):
         """重试失败的投递任务
 
